pub enum OneOrCollection<T> {
One(T),
Collection(T),
}Expand description
One item or collection of items for types.
This is common construction in compiler when we need to describe singleton or collection of items of specific type.
Variants
Implementations
Sourceimpl<'a> OneOrCollection<(TypeInfo, QualifiedName<'a>)>
impl<'a> OneOrCollection<(TypeInfo, QualifiedName<'a>)>
Sourcepub const fn name(&self) -> QualifiedName<'a>
pub const fn name(&self) -> QualifiedName<'a>
Qualified type name of the property.
Sourceimpl<'a> OneOrCollection<QualifiedName<'a>>
impl<'a> OneOrCollection<QualifiedName<'a>>
Sourcepub const fn name(&self) -> QualifiedName<'a>
pub const fn name(&self) -> QualifiedName<'a>
Qualified type name of the property.
Sourceimpl OneOrCollection<TaggedType<QualifiedName, QualifiedTypeNameTag>>
impl OneOrCollection<TaggedType<QualifiedName, QualifiedTypeNameTag>>
pub const fn qualified_type_name(&self) -> &QualifiedTypeName
Sourceimpl<T> OneOrCollection<T>
impl<T> OneOrCollection<T>
Sourcepub fn map<F, R>(self, f: F) -> OneOrCollection<R>where
F: FnOnce(T) -> R,
pub fn map<F, R>(self, f: F) -> OneOrCollection<R>where
F: FnOnce(T) -> R,
Maps inner value with funciton f.
Sourcepub const fn as_ref(&self) -> OneOrCollection<&T>
pub const fn as_ref(&self) -> OneOrCollection<&T>
Convert from OneOrCollection<T> to OneOrCollection<&T>.